/*
 * This file is part of the Aaru Data Preservation Suite.
 * Copyright (c) 2019-2026 Natalia Portillo.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef LIBAARUFORMAT_USAGE_H
#define LIBAARUFORMAT_USAGE_H

void print_banner();
void usage();
void usage_identify();
void usage_info();
void usage_read();
void usage_read_long();
void usage_verify();
void usage_verify_sectors();
void usage_compare();
void usage_cli_compare();
void usage_convert();
void usage_upgrade_ddt_to_alpha21();
void usage_inject_media_tag();
void usage_convert_ps3();
void usage_convert_wiiu();
void usage_convert_ngcw();

#endif  // LIBAARUFORMAT_USAGE_H
